/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.egeria.connectors.ibm.datastage.dataengineconnector.mapping;

import org.odpi.egeria.connectors.ibm.datastage.dataengineconnector.DataStageConnector;
import org.odpi.egeria.connectors.ibm.datastage.dataengineconnector.auditlog.DataStageErrorCode;
import org.odpi.egeria.connectors.ibm.datastage.dataengineconnector.model.DataStageCache;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.errors.IGCConnectivityException;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.errors.IGCException;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.errors.IGCIOException;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.errors.IGCParsingException;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.model.base.InformationAsset;
import org.odpi.egeria.connectors.ibm.igc.clientlibrary.model.common.Reference;
import org.odpi.openmetadata.accessservices.dataengine.model.Collection;

/**
 * Mappings for creating a TransformationObject.
 */
public class TransformationProjectMapping extends BaseMapping{

    private static final String TRANSFORMATION_PROJECT_KEY = "transformation_project";

    /**
     * Default constructor to pass in the cache for re-use.
     *
     * @param cache used by this mapping
     */
    TransformationProjectMapping(DataStageCache cache) {
        super(cache);
    }

    /**
     * Retrieves the transformation project from an asset's context and returns it or null if it does not exists
     *
     * @param igcObj the asset for which to obtain the transformation project
     * @return Collection
     */
    public Collection getTransformationProject(InformationAsset igcObj) throws IGCException {
        if (igcObj == null) {
            return null;
        }
        String methodName = "getTransformationProject";
        for (Reference reference : igcObj.getContext()) {
            if (TRANSFORMATION_PROJECT_KEY.equals(reference.getType())) {
                Collection transformationProject = new Collection();
                String qualifiedName = getQualifiedName(reference);
                transformationProject.setQualifiedName(qualifiedName);
                transformationProject.setName(reference.getName());
                return transformationProject;
            }
        }
        return null;
    }

    private String getQualifiedName(Reference reference) throws IGCException {
        return getFullyQualifiedName(reference);
    }
}
